<?php

namespace SGalinski\SgJobs\Service;

/***************************************************************
 *  Copyright notice
 *
 *  (c) sgalinski Internet Services (https://www.sgalinski.de)
 *
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
 *  free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 3 of the License, or
 *  (at your option) any later version.
 *
 *  The GNU General Public License can be found at
 *  http://www.gnu.org/copyleft/gpl.html.
 *
 *  This script is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  This copyright notice MUST APPEAR in all copies of the script!
 ***************************************************************/

use SJBR\StaticInfoTables\Domain\Model\Country;
use SJBR\StaticInfoTables\Domain\Repository\CountryRepository;
use SJBR\StaticInfoTables\Hook\Backend\Form\FormDataProvider\TcaSelectItemsProcessor;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Object\ObjectManager;

/**
 * Class TcaItemsProcessor
 *
 * @package SGalinski\SgJobs\Service
 */
class TcaItemsProcessor extends TcaSelectItemsProcessor {

	/**
	 * returns the country options from static info tables
	 *
	 * @param array $PA
	 * @throws \InvalidArgumentException
	 */
	public function getCountryOptions(array $PA) {
		$items = $PA['items'];
		$objectManager = GeneralUtility::makeInstance(ObjectManager::class);
		/** @var CountryRepository $countryRepository */
		$countryRepository = $objectManager->get(CountryRepository::class);
		$objects = $countryRepository->findAllOrderedBy('shortNameEn')->toArray();

		// Index rows by uid
		$uidIndexedObjects = [];
		if (!empty($objects)) {
			/** @var Country $object */
			foreach ($objects as $object) {
				$uidIndexedObjects[$object->getUid()] = $object;
				$items[] = [$object->getShortNameEn(), $object->getUid()];
			}
		}

		$items = $this->translateSelectorItems($items, 'static_countries');

		if (\count($items) > 1) {
			foreach ($items as $key => $item) {
				$object = NULL;
				if ($item[1] && $object = $uidIndexedObjects[$item[1]]) {
					$items[$key][1] = $object->getIsoCodeA3();
				}
			}
		}
		$PA['items'] = $items;
	}
}
